==> qtjambi-multimediawidgets-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimediaWidgets/QVideoWidgetControl_shell.h <==
#ifndef QVIDEOWIDGETCONTROL_SHELL_H
#define QVIDEOWIDGETCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimediaWidgets/qvideowidgetcontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QVideoWidgetControl_shell : public QVideoWidgetControl, public QtJambiShellInterface
{
public:
    QVideoWidgetControl_shell(QObject* parent0 = nullptr);
    ~QVideoWidgetControl_shell() override;

    Qt::AspectRatioMode aspectRatioMode() const override;
    int brightness() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    int contrast() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int hue() const override;
    bool isFullScreen() const override;
    int saturation() const override;
    void setAspectRatioMode(Qt::AspectRatioMode mode0) override;
    void setBrightness(int brightness0) override;
    void setContrast(int contrast0) override;
    void setFullScreen(bool fullScreen0) override;
    void setHue(int hue0) override;
    void setSaturation(int saturation0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* videoWidget() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVideoWidgetControl_access : public QVideoWidgetControl
{
    jint __qt_aspectRatioMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_brightness(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_contrast(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_hue(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isFullScreen(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_saturation(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setAspectRatioMode_Qt_AspectRatioMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
    void __qt_setBrightness_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint brightness0);
    void __qt_setContrast_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint contrast0);
    void __qt_setFullScreen_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean fullScreen0);
    void __qt_setHue_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint hue0);
    void __qt_setSaturation_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint saturation0);
    jobject __qt_videoWidget(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QVIDEOWIDGETCONTROL_SHELL_H

==> qtjambi-multimediawidgets-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimediaWidgets/QVideoWidgetControl_shell.h <==
#ifndef QVIDEOWIDGETCONTROL_SHELL_H
#define QVIDEOWIDGETCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimediaWidgets/qvideowidgetcontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QVideoWidgetControl_shell : public QVideoWidgetControl, public QtJambiShellInterface
{
public:
    QVideoWidgetControl_shell(QObject* parent0 = nullptr);
    ~QVideoWidgetControl_shell() override;

    Qt::AspectRatioMode aspectRatioMode() const override;
    int brightness() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    int contrast() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    int hue() const override;
    bool isFullScreen() const override;
    int saturation() const override;
    void setAspectRatioMode(Qt::AspectRatioMode mode0) override;
    void setBrightness(int brightness0) override;
    void setContrast(int contrast0) override;
    void setFullScreen(bool fullScreen0) override;
    void setHue(int hue0) override;
    void setSaturation(int saturation0) override;
    void timerEvent(QTimerEvent* event0) override;
    QWidget* videoWidget() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVideoWidgetControl_access : public QVideoWidgetControl
{
    jint __qt_aspectRatioMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_brightness_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_contrast_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_hue_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isFullScreen_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_saturation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setAspectRatioMode_Qt_AspectRatioMode(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint mode0);
    void __qt_setBrightness_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint brightness0);
    void __qt_setContrast_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint contrast0);
    void __qt_setFullScreen_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean fullScreen0);
    void __qt_setHue_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint hue0);
    void __qt_setSaturation_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint saturation0);
    jobject __qt_videoWidget(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QVIDEOWIDGETCONTROL_SHELL_H
